layouttools.SpacingIndication
=============================

.. abjad-lineage:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication

.. autoclass:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.normalized_spacing_duration
   :noindex:

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.proportional_notation_duration
   :noindex:

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.storage_format
   :noindex:

.. autoattribute:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.tempo_indication
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__eq__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__ge__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__gt__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__le__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__lt__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__ne__
   :noindex:

.. automethod:: abjad.tools.layouttools.SpacingIndication.SpacingIndication.SpacingIndication.__repr__
   :noindex:
